<?php
/**
 * @file
 * Describes the ND Genotypes Bulk Loader Template
 */

/**
 * Create a Generic Genotype Experiment Bulk Loader and save it to the
 * tripal_bulk_loader_template table for use in Bulk Loading Jobs
 *
 * Assumes a tsv file with the following columns:
 *  - feature.uniquename: the marker the genotypes should be associated with (must already exist)
 *  - genotype.description: the actual genotype called (ie: AA, 300bp, present, etc.)
 *
 * The following fields are constants per bulk loading job and will be able to be entered
 * once the job is created (* -required):
 * ( currently the template needs to be edited )
 *  - stock.uniquename*: the stock the genotypes were called in (must already exist)
 *  - genotype column*: column the genotypes are in (index starts at 1)
 *  - project.uniquename*: the project to associate the genotypes with (must already exist)
 *  - nd_geolocation.description*: the location the genotyping experiment took place at (must already exist)
 *
 * This loader will create the following records (number of records per line in the file):
 *  - nd_experiment (1)
 *  - nd_experiment_genotype (1)
 *  - genotype record (0 or 1 -depending on if it already exists for that feature)
 *  - feature_genotype (0 or 1 -depending on if it already exists for that feature)
 *  - nd_experment_project (1)
 *  - nd_experiment_stock (1)
 *
 * @return
 *   template_id on success (both insert and update) and FALSE otherwise
 */
function nd_genotypes_add_generic_experiment_bulk_loader ($update = FALSE) {

	$template_name = 'ND Genotype: Generic Genotype Experiments';
	$serialized_template = 'a:19:{i:0;a:9:{s:5:"table";s:8:"organism";s:9:"record_id";s:8:"Organism";s:6:"fields";a:2:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:5:"Genus";s:5:"field";s:5:"genus";s:8:"required";i:0;s:14:"constant value";s:0:"";s:7:"exposed";i:1;s:16:"exposed_validate";i:0;}i:1;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:7:"Species";s:5:"field";s:7:"species";s:8:"required";i:0;s:14:"constant value";s:0:"";s:7:"exposed";i:1;s:16:"exposed_validate";i:0;}}s:4:"mode";s:11:"select_once";s:19:"select_if_duplicate";i:0;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:1;a:9:{s:5:"table";s:2:"cv";s:9:"record_id";s:11:"Sequence CV";s:6:"fields";a:1:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:4:"Name";s:5:"field";s:4:"name";s:8:"required";i:0;s:14:"constant value";s:8:"sequence";s:7:"exposed";i:0;s:16:"exposed_validate";i:1;}}s:4:"mode";s:11:"select_once";s:19:"select_if_duplicate";i:0;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:2;a:9:{s:5:"table";s:2:"cv";s:9:"record_id";s:15:"Relationship CV";s:6:"fields";a:1:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:4:"Name";s:5:"field";s:4:"name";s:8:"required";i:0;s:14:"constant value";s:12:"relationship";s:7:"exposed";i:0;s:16:"exposed_validate";i:1;}}s:4:"mode";s:11:"select_once";s:19:"select_if_duplicate";i:0;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:3;a:9:{s:5:"table";s:6:"cvterm";s:9:"record_id";s:11:"Marker Type";s:6:"fields";a:2:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:4:"Name";s:5:"field";s:4:"name";s:8:"required";i:0;s:14:"constant value";s:14:"genetic_marker";s:7:"exposed";i:0;s:16:"exposed_validate";i:1;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:2:"CV";s:5:"field";s:5:"cv_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:11:"Sequence CV";s:13:"foreign field";s:5:"cv_id";s:8:"required";i:0;}}s:4:"mode";s:11:"select_once";s:19:"select_if_duplicate";i:0;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:4;a:9:{s:5:"table";s:7:"feature";s:9:"record_id";s:6:"Marker";s:6:"fields";a:4:{i:0;a:7:{s:4:"type";s:11:"table field";s:5:"title";s:11:"Unique Name";s:5:"field";s:10:"uniquename";s:8:"required";i:0;s:18:"spreadsheet column";s:1:"1";s:7:"exposed";i:0;s:19:"exposed_description";s:0:"";}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:8:"Organism";s:5:"field";s:11:"organism_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:8:"Organism";s:13:"foreign field";s:11:"organism_id";s:8:"required";i:0;}i:2;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:4:"Type";s:5:"field";s:7:"type_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:11:"Marker Type";s:13:"foreign field";s:9:"cvterm_id";s:8:"required";i:0;}i:3;a:7:{s:4:"type";s:11:"table field";s:5:"title";s:4:"Name";s:5:"field";s:4:"name";s:8:"required";i:0;s:18:"spreadsheet column";s:1:"1";s:7:"exposed";i:0;s:19:"exposed_description";s:0:"";}}s:4:"mode";s:6:"insert";s:19:"select_if_duplicate";i:1;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:5;a:9:{s:5:"table";s:6:"cvterm";s:9:"record_id";s:10:"Stock Type";s:6:"fields";a:2:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:4:"Name";s:5:"field";s:4:"name";s:8:"required";i:0;s:14:"constant value";s:11:"genomic_DNA";s:7:"exposed";i:0;s:16:"exposed_validate";i:1;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:2:"CV";s:5:"field";s:5:"cv_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:11:"Sequence CV";s:13:"foreign field";s:5:"cv_id";s:8:"required";i:0;}}s:4:"mode";s:11:"select_once";s:19:"select_if_duplicate";i:0;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:6;a:9:{s:5:"table";s:5:"stock";s:9:"record_id";s:5:"Stock";s:6:"fields";a:4:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:27:"Germplasm/Stock Unique Name";s:5:"field";s:10:"uniquename";s:8:"required";i:0;s:14:"constant value";s:0:"";s:7:"exposed";i:1;s:16:"exposed_validate";i:0;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:4:"Type";s:5:"field";s:7:"type_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:10:"Stock Type";s:13:"foreign field";s:9:"cvterm_id";s:8:"required";i:0;}i:2;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:8:"Organism";s:5:"field";s:11:"organism_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:8:"Organism";s:13:"foreign field";s:11:"organism_id";s:8:"required";i:0;}i:3;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:20:"Germplasm/Stock Name";s:5:"field";s:4:"name";s:8:"required";i:0;s:14:"constant value";s:0:"";s:7:"exposed";i:1;s:16:"exposed_validate";i:0;}}s:4:"mode";s:6:"insert";s:19:"select_if_duplicate";i:1;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:7;a:9:{s:5:"table";s:6:"cvterm";s:9:"record_id";s:13:"Genotype Type";s:6:"fields";a:2:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:4:"Name";s:5:"field";s:4:"name";s:8:"required";i:0;s:14:"constant value";s:8:"genotype";s:7:"exposed";i:0;s:16:"exposed_validate";i:1;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:2:"CV";s:5:"field";s:5:"cv_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:11:"Sequence CV";s:13:"foreign field";s:5:"cv_id";s:8:"required";i:0;}}s:4:"mode";s:11:"select_once";s:19:"select_if_duplicate";i:0;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:8;a:9:{s:5:"table";s:8:"genotype";s:9:"record_id";s:8:"Genotype";s:6:"fields";a:3:{i:0;a:7:{s:4:"type";s:11:"table field";s:5:"title";s:11:"Allele Call";s:5:"field";s:11:"description";s:8:"required";i:0;s:18:"spreadsheet column";s:1:"2";s:7:"exposed";i:1;s:19:"exposed_description";s:101:"Enter the column number that contains the allele calls for the current stock (the first column is 1).";}i:1;a:8:{s:4:"type";s:11:"table field";s:5:"title";s:23:"Unique Name (Generated)";s:5:"field";s:10:"uniquename";s:8:"required";i:0;s:18:"spreadsheet column";s:1:"2";s:7:"exposed";i:1;s:19:"exposed_description";s:101:"Enter the column number that contains the allele calls for the current stock (the first column is 1).";s:5:"regex";a:2:{s:7:"pattern";a:1:{i:0;s:8:"/^(.*)$/";}s:7:"replace";a:1:{i:0;s:15:"<#column:1#>_\1";}}}i:2;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:4:"Type";s:5:"field";s:7:"type_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:13:"Genotype Type";s:13:"foreign field";s:9:"cvterm_id";s:8:"required";i:0;}}s:4:"mode";s:6:"insert";s:19:"select_if_duplicate";i:1;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:9;a:9:{s:5:"table";s:6:"cvterm";s:9:"record_id";s:26:"Genotype Feature Link Type";s:6:"fields";a:2:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:4:"Name";s:5:"field";s:4:"name";s:8:"required";i:0;s:14:"constant value";s:12:"derives_from";s:7:"exposed";i:0;s:16:"exposed_validate";i:1;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:2:"CV";s:5:"field";s:5:"cv_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:15:"Relationship CV";s:13:"foreign field";s:5:"cv_id";s:8:"required";i:0;}}s:4:"mode";s:11:"select_once";s:19:"select_if_duplicate";i:0;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:10;a:9:{s:5:"table";s:16:"feature_genotype";s:9:"record_id";s:24:"Genotype => Feature Link";s:6:"fields";a:5:{i:0;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:8:"Genotype";s:5:"field";s:11:"genotype_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:8:"Genotype";s:13:"foreign field";s:11:"genotype_id";s:8:"required";i:0;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:16:"Feature (Marker)";s:5:"field";s:10:"feature_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:6:"Marker";s:13:"foreign field";s:10:"feature_id";s:8:"required";i:0;}i:2;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:4:"Type";s:5:"field";s:9:"cvterm_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:26:"Genotype Feature Link Type";s:13:"foreign field";s:9:"cvterm_id";s:8:"required";i:0;}i:3;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:4:"Rank";s:5:"field";s:4:"rank";s:8:"required";i:0;s:14:"constant value";s:1:"0";s:7:"exposed";i:0;s:16:"exposed_validate";i:0;}i:4;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:6:"CGroup";s:5:"field";s:6:"cgroup";s:8:"required";i:0;s:14:"constant value";s:1:"0";s:7:"exposed";i:0;s:16:"exposed_validate";i:0;}}s:4:"mode";s:6:"insert";s:19:"select_if_duplicate";i:1;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:11;a:9:{s:5:"table";s:6:"cvterm";s:9:"record_id";s:18:"ND Experiment Type";s:6:"fields";a:2:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:4:"Name";s:5:"field";s:4:"name";s:8:"required";i:0;s:14:"constant value";s:8:"genotype";s:7:"exposed";i:0;s:16:"exposed_validate";i:1;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:2:"CV";s:5:"field";s:5:"cv_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:11:"Sequence CV";s:13:"foreign field";s:5:"cv_id";s:8:"required";i:0;}}s:4:"mode";s:11:"select_once";s:19:"select_if_duplicate";i:0;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:12;a:9:{s:5:"table";s:14:"nd_geolocation";s:9:"record_id";s:11:"Geolocation";s:6:"fields";a:1:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:20:"Location Description";s:5:"field";s:11:"description";s:8:"required";i:0;s:14:"constant value";s:0:"";s:7:"exposed";i:1;s:16:"exposed_validate";i:0;}}s:4:"mode";s:11:"insert_once";s:19:"select_if_duplicate";i:1;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:13;a:3:{s:5:"table";s:13:"nd_experiment";s:9:"record_id";s:13:"ND Experiment";s:6:"fields";a:2:{i:0;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:4:"Type";s:5:"field";s:7:"type_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:18:"ND Experiment Type";s:13:"foreign field";s:9:"cvterm_id";s:8:"required";i:0;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:11:"Geolocation";s:5:"field";s:17:"nd_geolocation_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:11:"Geolocation";s:13:"foreign field";s:17:"nd_geolocation_id";s:8:"required";i:0;}}}i:14;a:3:{s:5:"table";s:22:"nd_experiment_genotype";s:9:"record_id";s:25:"ND Experiment => Genotype";s:6:"fields";a:2:{i:0;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:13:"ND Experiment";s:5:"field";s:16:"nd_experiment_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:13:"ND Experiment";s:13:"foreign field";s:16:"nd_experiment_id";s:8:"required";i:0;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:8:"Genotype";s:5:"field";s:11:"genotype_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:8:"Genotype";s:13:"foreign field";s:11:"genotype_id";s:8:"required";i:0;}}}i:15;a:9:{s:5:"table";s:6:"cvterm";s:9:"record_id";s:29:"Nd Experiment Stock Link Type";s:6:"fields";a:2:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:4:"Name";s:5:"field";s:4:"name";s:8:"required";i:0;s:14:"constant value";s:15:"has_participant";s:7:"exposed";i:0;s:16:"exposed_validate";i:1;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:2:"CV";s:5:"field";s:5:"cv_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:15:"Relationship CV";s:13:"foreign field";s:5:"cv_id";s:8:"required";i:0;}}s:4:"mode";s:11:"select_once";s:19:"select_if_duplicate";i:0;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:16;a:3:{s:5:"table";s:19:"nd_experiment_stock";s:9:"record_id";s:22:"ND Experiment => Stock";s:6:"fields";a:3:{i:0;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:13:"ND Experiment";s:5:"field";s:16:"nd_experiment_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:13:"ND Experiment";s:13:"foreign field";s:16:"nd_experiment_id";s:8:"required";i:0;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:5:"Stock";s:5:"field";s:8:"stock_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:5:"Stock";s:13:"foreign field";s:8:"stock_id";s:8:"required";i:0;}i:2;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:4:"Type";s:5:"field";s:7:"type_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:29:"Nd Experiment Stock Link Type";s:13:"foreign field";s:9:"cvterm_id";s:8:"required";i:0;}}}i:18;a:9:{s:5:"table";s:7:"project";s:9:"record_id";s:7:"Project";s:6:"fields";a:2:{i:0;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:12:"Project Name";s:5:"field";s:4:"name";s:8:"required";i:0;s:14:"constant value";s:0:"";s:7:"exposed";i:1;s:16:"exposed_validate";i:0;}i:1;a:7:{s:4:"type";s:8:"constant";s:5:"title";s:11:"Description";s:5:"field";s:11:"description";s:8:"required";i:0;s:14:"constant value";s:38:"A Natural Diversity Genotypes project.";s:7:"exposed";i:0;s:16:"exposed_validate";i:0;}}s:4:"mode";s:11:"insert_once";s:19:"select_if_duplicate";i:1;s:19:"update_if_duplicate";i:0;s:15:"select_optional";i:0;s:7:"disable";i:0;s:8:"optional";i:0;}i:19;a:3:{s:5:"table";s:21:"nd_experiment_project";s:9:"record_id";s:24:"ND Experiment => Project";s:6:"fields";a:2:{i:0;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:7:"Project";s:5:"field";s:10:"project_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:7:"Project";s:13:"foreign field";s:10:"project_id";s:8:"required";i:0;}i:1;a:7:{s:4:"type";s:11:"foreign key";s:5:"title";s:13:"ND Experiment";s:5:"field";s:16:"nd_experiment_id";s:16:"show_all_records";i:0;s:11:"foreign key";s:13:"ND Experiment";s:13:"foreign field";s:16:"nd_experiment_id";s:8:"required";i:0;}}}}';
	$record = array(
		'name' => $template_name,
		'template_array' => $serialized_template,
		'changed' => time()
	);

	// Check if it already exists
	$template_id = db_query(
	  'SELECT template_id FROM {tripal_bulk_loader_template} WHERE name=:name',
	  array(':name' => $record['name'])
	)->fetchField();

	if ($template_id) {
		$record['template_id'] = $template_id;
		if ($update) {
			// Update the existing template
			$success = drupal_write_record('tripal_bulk_loader_template',$record,'template_id');
			if ($success) {
				drupal_set_message('ND Genotype: Generic Genotype Experiments Bulk Loader Template Updated');
				return $template_id;
			} else {
				drupal_set_message('Unable to update ND Genotype: Generic Genotype Experiments Bulk Loader Template','error');
				return FALSE;
			}
		} else {
			drupal_set_message('ND Genotype: Generic Genotype Experiments Bulk Loader Template already exists.','warning');
			return $template_id;
		}


	// if it doesn't already exist then insert it
	} else {
	  $record['created'] = time();
		$success = drupal_write_record('tripal_bulk_loader_template',$record);
		if ($success) {
			drupal_set_message('ND Genotype: Generic Genotype Experiments Bulk Loader Template Created');
			return $success['template_id'];
		} else {
			drupal_set_message('Unable to create ND Genotype: Generic Genotype Experiments Bulk Loader Template','error');
			return FALSE;
		}
	}

}